--- a/configure.ac	2016-02-06 17:08:05.505990463 +0100
+++ b/configure.ac	2016-02-06 17:08:42.316530268 +0100
@@ -15,18 +15,22 @@
 AC_INIT([libixion], [ixion_version])
 AC_CONFIG_HEADERS([config.h])
 AM_INIT_AUTOMAKE([1.11 foreign dist-bzip2 dist-xz])
-AM_PATH_PYTHON(2.7.0)
 m4_ifdef([AM_SILENT_RULES], [AM_SILENT_RULES([yes])])
 
 AC_ARG_WITH(hash-container-compat,
 [
   --with-hash-container-compat use std::hash_foo instead of boost::unordered_foo
 ],
 ,with_hash_container_compat=no)
 
 AC_ARG_WITH(mdds-include-path,
     AS_HELP_STRING([--with-mdds-include-path], [specify include path for mdds headers.])
 ,)
+AC_ARG_ENABLE([python],
+    [AS_HELP_STRING([--disable-python], [Disable python bindings])],
+    [enable_python="$enableval"],
+    [enable_python=yes]
+)
 
 IXION_API_VERSION=ixion_api_version
 IXION_MAJOR_VERSION=ixion_major_version
@@ -70,7 +74,11 @@
 PKG_CHECK_MODULES([MDDS],[mdds >= 0.12.0])
 
 # Check for python.
-PKG_CHECK_MODULES([PYTHON], [python >= 0.27.1])
+AS_IF([test "x$enable_python" != "xno"], [
+    AM_PATH_PYTHON(2.7.0)
+    PKG_CHECK_MODULES([PYTHON], [python >= 0.27.1])
+])
+AM_CONDITIONAL([BUILD_PYTHON], [test "x$enable_python" != "xno"])
 
 CPPFLAGS="$CPPFLAGS -g -Os -fvisibility=hidden"
 
@@ -101,3 +109,10 @@
                  src/libixion/constants.inl
                  src/python/Makefile])
 AC_OUTPUT
+
+AC_MSG_NOTICE([
+==============================================================================
+Build configuration:
+	python:               $enable_python
+==============================================================================
+])
--- a/src/python/Makefile.am	2016-02-06 17:08:12.138907540 +0100
+++ b/src/python/Makefile.am	2016-02-06 17:08:38.034583800 +0100
@@ -1,3 +1,5 @@
+if BUILD_PYTHON
+
 pyexec_LTLIBRARIES = ixion.la
 ixion_la_SOURCES = \
 	document.hpp \
@@ -16,3 +18,5 @@
 
 AM_TESTS_ENVIRONMENT = PYTHONPATH=.libs$${PYTHONPATH:+:$${PYTHONPATH}}; export PYTHONPATH;
 TESTS = ../../test/ixion-python-test.py
+
+endif
